# opstrat
opstrat is a Python library for visualizing options.

## Latest Version 
0.0.18

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install opstrat.

```bash
pip install opstrat
```

## Usage

```python
import opstrat

opstrat.basic.option_plotter() # plots a basic option payoff diagram
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## Content License
[MIT](https://choosealicense.com/licenses/mit/)


